==> zio-aws-apigatewayv2_2.13-5.17.121.2-sources.jar: zio/aws/apigatewayv2/model/GetRouteResponseRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetRouteResponseRequest(
    apiId: __string,
    routeId: __string,
    routeResponseId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest = {
    import GetRouteResponseRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .routeId(__string.unwrap(routeId): java.lang.String)
      .routeResponseId(__string.unwrap(routeResponseId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetRouteResponseRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetRouteResponseRequest.wrap(buildAwsValue())
}
object GetRouteResponseRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetRouteResponseRequest =
      zio.aws.apigatewayv2.model
        .GetRouteResponseRequest(apiId, routeId, routeResponseId)
    def apiId: __string
    def routeId: __string
    def routeResponseId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getRouteId: ZIO[Any, Nothing, __string] = ZIO.succeed(routeId)
    def getRouteResponseId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(routeResponseId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest
  ) extends zio.aws.apigatewayv2.model.GetRouteResponseRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val routeId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.routeId())
    override val routeResponseId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.routeResponseId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest
  ): zio.aws.apigatewayv2.model.GetRouteResponseRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_2.13-7.21.15.2-sources.jar: zio/aws/apigatewayv2/model/GetRouteResponseRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetRouteResponseRequest(
    apiId: __string,
    routeId: __string,
    routeResponseId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest = {
    import GetRouteResponseRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .routeId(routeId: java.lang.String)
      .routeResponseId(routeResponseId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetRouteResponseRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetRouteResponseRequest.wrap(buildAwsValue())
}
object GetRouteResponseRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetRouteResponseRequest =
      zio.aws.apigatewayv2.model
        .GetRouteResponseRequest(apiId, routeId, routeResponseId)
    def apiId: __string
    def routeId: __string
    def routeResponseId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getRouteId: ZIO[Any, Nothing, __string] = ZIO.succeed(routeId)
    def getRouteResponseId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(routeResponseId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest
  ) extends zio.aws.apigatewayv2.model.GetRouteResponseRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val routeId: __string = impl.routeId(): __string
    override val routeResponseId: __string = impl.routeResponseId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRouteResponseRequest
  ): zio.aws.apigatewayv2.model.GetRouteResponseRequest.ReadOnly = new Wrapper(
    impl
  )
}
